==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/UtmArgumentResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for UtmArgument
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class UtmArgumentResponseProjection extends GraphQLResponseProjection {

    public UtmArgumentResponseProjection() {
    }

    @Override
    public UtmArgumentResponseProjection all$() {
        return all$(3);
    }

    @Override
    public UtmArgumentResponseProjection all$(int maxDepth) {
        this.id();
        this.utmKey();
        this.userKey();
        this.typename();
        return this;
    }

    public UtmArgumentResponseProjection id() {
        return id(null);
    }

    public UtmArgumentResponseProjection id(String alias) {
        fields.add(new GraphQLResponseField("id").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection utmKey() {
        return utmKey(null);
    }

    public UtmArgumentResponseProjection utmKey(String alias) {
        fields.add(new GraphQLResponseField("utmKey").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection userKey() {
        return userKey(null);
    }

    public UtmArgumentResponseProjection userKey(String alias) {
        fields.add(new GraphQLResponseField("userKey").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection typename() {
        return typename(null);
    }

    public UtmArgumentResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/UtmArgumentResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for UtmArgument
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class UtmArgumentResponseProjection extends GraphQLResponseProjection {

    public UtmArgumentResponseProjection() {
    }

    @Override
    public UtmArgumentResponseProjection all$() {
        return all$(3);
    }

    @Override
    public UtmArgumentResponseProjection all$(int maxDepth) {
        this.id();
        this.utmKey();
        this.userKey();
        this.typename();
        return this;
    }

    public UtmArgumentResponseProjection id() {
        return id(null);
    }

    public UtmArgumentResponseProjection id(String alias) {
        fields.add(new GraphQLResponseField("id").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection utmKey() {
        return utmKey(null);
    }

    public UtmArgumentResponseProjection utmKey(String alias) {
        fields.add(new GraphQLResponseField("utmKey").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection userKey() {
        return userKey(null);
    }

    public UtmArgumentResponseProjection userKey(String alias) {
        fields.add(new GraphQLResponseField("userKey").alias(alias));
        return this;
    }

    public UtmArgumentResponseProjection typename() {
        return typename(null);
    }

    public UtmArgumentResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
